<?php

/**
 * @file
 * Definition of Drupal\yamlform\test\YamlFormSubmissionListBuilderTest.
 */

namespace Drupal\yamlform\Tests;

/**
 * Tests for YAML form submission list builder.
 *
 * @group YamlForm
 */
class YamlFormSubmissionListBuilderTest extends YamlFormTestBase {

  /**
   * Tests results.
   */
  public function testResults() {
    /** @var \Drupal\yamlform\YamlFormInterface $yamlform */
    /** @var \Drupal\yamlform\YamlFormSubmissionInterface[] $submissions */
    list($yamlform, $submissions) = $this->createYamlFormWithSubmissions();

    // Make the second submission to be starred (aka sticky).
    $submissions[1]->setSticky(TRUE)->save();

    $this->drupalLogin($this->adminSubmissionUser);

    $this->drupalGet('admin/structure/yamlform/manage/' . $yamlform->id() . '/results/table');

    // Check state options with totals.
    $this->assertRaw('<select data-drupal-selector="edit-state" id="edit-state" name="state" class="form-select"><option value="" selected="selected">All [3]</option><option value="starred">Starred [1]</option><option value="unstarred">Unstarred [2]</option></select>');

    // Check results with no filtering.
    $this->assertLinkByHref($submissions[0]->toUrl()->toString());
    $this->assertLinkByHref($submissions[1]->toUrl()->toString());
    $this->assertLinkByHref($submissions[2]->toUrl()->toString());
    $this->assertRaw($submissions[0]->getData('first_name'));
    $this->assertRaw($submissions[1]->getData('first_name'));
    $this->assertRaw($submissions[2]->getData('first_name'));
    $this->assertNoFieldById('edit-reset', 'reset');

    // Check results filtered by key(word).
    $this->drupalPostForm('admin/structure/yamlform/manage/' . $yamlform->id() . '/results/table', ['search' => $submissions[0]->getData('first_name')], t('Filter'));
    $this->assertUrl('admin/structure/yamlform/manage/' . $yamlform->id() . '/results/table?search=' . $submissions[0]->getData('first_name') . '&state=');
    $this->assertRaw($submissions[0]->getData('first_name'));
    $this->assertNoRaw($submissions[1]->getData('first_name'));
    $this->assertNoRaw($submissions[2]->getData('first_name'));
    $this->assertFieldById('edit-reset', 'Reset');

    // Check results filtered by state.
    $this->drupalPostForm('admin/structure/yamlform/manage/' . $yamlform->id() . '/results/table', ['state' => 'starred'], t('Filter'));
    $this->assertUrl('admin/structure/yamlform/manage/' . $yamlform->id() . '/results/table?search=&state=starred');
    $this->assertRaw('<option value="starred" selected="selected">Starred [1]</option>');
    $this->assertNoRaw($submissions[0]->getData('first_name'));
    $this->assertRaw($submissions[1]->getData('first_name'));
    $this->assertNoRaw($submissions[2]->getData('first_name'));
    $this->assertFieldById('edit-reset', 'Reset');
  }

}
