<?php

/**
 * @file
 * Contains \Drupal\yamlform\YamlFormDialogTrait.
 */

namespace Drupal\yamlform;

use Drupal\Core\Ajax\AjaxResponse;
use Drupal\Core\Ajax\HtmlCommand;
use Drupal\Core\EventSubscriber\MainContentViewSubscriber;
use Drupal\Core\Form\FormStateInterface;

/**
 * Trait class YAML form dialogs.
 */
trait YamlFormDialogTrait {

  /**
   * Is the current request for an AJAX modal dialog.
   *
   * @return bool
   *   TRUE is the current request if for an AJAX modal dialog.
   */
  protected function isModalDialog() {
    $wrapper_format = $this->getRequest()->get(MainContentViewSubscriber::WRAPPER_FORMAT);
    return (in_array($wrapper_format, ['drupal_ajax', 'drupal_modal'])) ? TRUE : FALSE;
  }

  /**
   * Add modal dialog support to a form.
   *
   * @param array $form
   *   An associative array containing the structure of the form.
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   The current state of the form.
   *
   * @return array
   *   The form with modal dialog support.
   */
  protected function buildDialog(array &$form, FormStateInterface $form_state) {
    $form['actions']['submit']['#ajax'] = [
      'callback' => '::submitForm',
      'event' => 'click',
    ];
    $form['#attached']['library'][] = 'core/drupal.dialog.ajax';
    $form['#prefix'] = '<div id="yamlform-dialog">';
    $form['#suffix'] = '</div>';
    return $form;
  }

  /**
   * Display validation error messages in modal dialog.
   *
   * @param array $form
   *   An associative array containing the structure of the form.
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   The current state of the form.
   *
   * @return bool|\Drupal\Core\Ajax\AjaxResponse
   *   An AJAX response that display validation error messages.
   */
  protected function validateDialog(array &$form, FormStateInterface $form_state) {
    if ($this->isModalDialog() && $form_state->hasAnyErrors()) {
      unset($form['#prefix'], $form['#suffix']);
      $form['status_messages'] = [
        '#type' => 'status_messages',
        '#weight' => -10,
      ];
      $response = new AjaxResponse();
      $response->addCommand(new HtmlCommand('#yamlform-dialog', $form));
      return $response;
    }
    return FALSE;
  }

}
